'''
A Django command to run Python scripts directly.
'''
import sys
from django.core.management.base import BaseCommand


def split_argv():
    '''
    Split the sys.argv into two halves,
    Django will use the first half,
    the second half will be pass to the user
    defined script.
    '''
    index = sys.argv.index('rundirect')
    after = []
    length = len(sys.argv)
    for i in range(index + 1, length):
        after.append(sys.argv.pop(index + 1))
    return sys.argv, after


class Command(BaseCommand):
    help = '''Run a script with django settings directly:

python manage.py rundirect SCRIPT.py [args] [options]

args and options are for the SCRIPT.py.
'''

    def __init__(self, *args, **options):
        BaseCommand.__init__(self, *args, **options)

    def handle(self, *args, **options):
        filename = self.after[0]
        sys.argv = self.after
        exec_globals = globals()
        exec_globals['__name__'] = '__main__'
        if sys.version_info.major == 2:
            execfile(filename, exec_globals)
        else:
            with open(filename) as fd:
                exec(fd.read(), exec_globals)

# Hack the sys.argv, make sure BaseComamnd.run_from_argv
# doesn't get any undeclared options.
Command.before, Command.after = split_argv()



'''
A Django command to run a single line of Python code.
'''
import sys
from django.core.management.base import BaseCommand


def split_argv():
    '''
    Split the sys.argv into two halves,
    Django will use the first half,
    the second half will be pass to the user
    defined script.
    '''
    index = sys.argv.index('runline')
    after = []
    length = len(sys.argv)
    for i in range(index + 1, length):
        after.append(sys.argv.pop(index + 1))
    return sys.argv, after


class Command(BaseCommand):
    help = '''Run a single line of Python code with django settings directly:

    python manage.py runline "<Your Commandline>"

Example:

    python manage.py runline "from django.contrib.auth.models import User;print User.objects.count()"
'''

    def __init__(self, *args, **options):
        BaseCommand.__init__(self, *args, **options)

    def handle(self, *args, **options):
        line = ' ' if not self.after else self.after[0]
        exec(line)

# Hack the sys.argv, make sure BaseComamnd.run_from_argv
# doesn't get any undeclared options.
Command.before, Command.after = split_argv()



#!/usr/bin/env python

long_description = ""

try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except:
    pass

sdict = {
    'name': 'django_rundirect',
    'version': "0.3.0",
    'license': 'MIT',
    'packages': ['django_rundirect',
                 'django_rundirect.management',
                 'django_rundirect.management.commands'],
    'package_dir': {'django_rundirect': 'django_rundirect'}, 
    'zip_safe': False,
    'install_requires': ['django'],
    'author': 'Lichun',
    'long_description': long_description,
    'url': 'https://github.com/socrateslee/django_rundirect',
    'classifiers': [
        'Environment :: Console',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python']
}

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

setup(**sdict)
